pub struct FactoryHdr {
pub num_iter: u8,
pub options: FactoryOpt,
}Expand description
CQC Factory Header
Additional header used to send factory information. Factory commands are used to tell the backend to do the following command or a sequence of commands multiple times.
Field Length Meaning
----- ------ -------
num_iter 1 byte Number of iterations to do the sequence.
options 1 byte Options when executing the factory.Fields
num_iter: u8options: FactoryOptImplementations