pub struct CmdHdr {
pub qubit_id: u16,
pub instr: Cmd,
pub options: CmdOpt,
}Expand description
CQC Command Header
A CQC Command Header identifies the specific instruction to execute, as well as the qubit ID on which to perform this instructions.
A CQC Command Header MUST follow the CQC Header for the following messages:
- Command
- Factory
- GetTime
Field Length Meaning
----- ------ -------
qubit_id 2 bytes Qubit ID to perform the operation on.
instr 1 byte Instruction to perform.
options 1 byte Options when executing the command.Notify
If the notify option bit is set, each of these commands return a CQC message Done indicating that execution has completed. Some commands also return additional messages, as described below:
- New: Returns a NewOk reply followed by an Extra Qubit header with the qubit ID.
- Measure(InPlace): Returns a MeasOut message followed by a Measurement Outcome header containing the measurement outcome.
- Recv: Returns a Recv reply followed by an Extra Qubit header with the qubit ID.
- Epr(Recv): Returns an EprOk reply by an Extra Qubit header and an Entanglement Information header.
Fields
qubit_id: u16instr: Cmdoptions: CmdOptImplementations